@@ -4,11 +4,13 @@ https://developers.google.com/analytics/
 devguides/reporting/core/v4/rest/v4/reports/batchGet
 """
 import pandas as pd
-
+from googlewrapper.connect import Connection
 
 class GoogleAnalytics:
-    def __init__(self, auth, view, default_view="df"):
+    def __init__(self, view, auth = Connection().ga(), default_view="df"):
         """
+        view: Google Analytics view ID
+          type: string
         auth: Google Analytics authentication object
           type: googleapiclient.discovery.Resource object
         """
